## Statistical analyses for Laughlin and Pomara (2023)
## Ornithology

## In the previous code, we calculated the slopes of the
## linear regressions of LCA ~ year for each species in
## ENA, ATL, and MISS. Now we need to calculate and add the other
## covariates to this dataframe before running the glms.

setwd("G:/My Drive/UNCA/Research/Range Shifts/New_submission/Ornithology submission/Revision 2/Ornithology_FinalVersions/Data_Dryad")
covs <- read.csv("cbc_covs_65species.csv")

## convert degrees latitude to total km (deg * 4440 = total km)
covs[,2:7] <- covs[,2:7] * 4440

######################
## Calculate Pearson's correlation between flyways
## Calculate mean LCA at start of study period (1980-82)
## Start with file with LCA data for all species, calculated
## using "RangeShifts_code.R". 

setwd("G:/My Drive/UNCA/Research/Range Shifts/New_submission/Ornithology submission/Revision 2/Ornithology_FinalVersions/Data_Dryad")
cbc <- read.csv('LCA_65species.csv')
sp_codes <- unique(sapply(strsplit(as.character(names(cbc[,2:ncol(cbc)])), split='_', fixed=TRUE), function(x) (x[1])))
cor <- NULL
lat_80 <- NULL

for (i in 1:length(sp_codes)){
  my_cor <- cor(cbc[,(3*(i-1))+3], cbc[,(3*(i-1))+4])
  cor[i] <- my_cor
  my_cor <- NULL
  my_mean <- mean(cbc[c(1:3),(3*(i-1))+2])
  lat_80[i] <- my_mean
  my_mean <- NULL
}
my.df <- data.frame(species=sp_codes, cor=cor, lat_1980=lat_80)

## merge with cbc_slopes_65species.csv
covs2 <- merge(covs, my.df, by="species")

## Next, remove AMRO from dataset. This species is an outlier
## and we removed it before running the following
## statistics (see text for details).
covs2 <- covs2[-4,]


#############
## Calculate s_within and s_between for each species

## s_within is simply the abs difference between flyways:
covs2$s_within <- abs(covs2$atl_all - covs2$miss_all)

## S_between calculation:
spec <- unique(covs2$species)
s_between <- NULL  # abs diff bt ENA_spec1 - ENA_spec all

for (k in 1:length(spec)){
  spec_f <- spec[k]
  my_fly1 <- covs2$ena_all[k]
  spec2 <- spec[-k]
  glm2 <- covs2[-k,]
  my_y1 <- NULL
  
  for (i in 1:length(spec2)){
    my_spec <- spec2[i]
    my_fly2 <- glm2$ena_all[i]
    my_y1[i] <- my_fly1 - my_fly2			# here, not taking abs yet.
  }
  s_between[k] <- abs(mean(my_y1, na.rm=T))			# here, taking abs of mean.
}
covs2$s_between <- s_between


#################################################
### General Linear Models and Model Selection ###

df <- covs2

## first, remove three irruptive species due to small
## sample size for this category (see text for details)
df <- df[c(-15, -41, -45),]

colnames(df)[c(3,5,7,11,13,14)] <- 
  c('ena', 'atl', 'miss', 'migratory','latitude','s_within')

## Model sets for model selection. All sets are identical
## for ENA, ATL, MISS, and s_within.

## ENA
m1 <- lm(ena ~ 1, data = df)
m2 <- lm(ena ~ migratory, data = df)
m3 <- lm(ena ~ latitude + I(latitude^2), data=df)
m4 <- lm(ena ~ insects, data = df)
m5 <- lm(ena ~ fruit + I(fruit^2), data = df)
m6 <- lm(ena ~ seeds, data = df)
m7 <- lm(ena ~ migratory + latitude + I(latitude^2), data = df)
m8 <- lm(ena ~ migratory + insects, data = df)
m9 <- lm(ena ~ migratory + fruit + I(fruit^2), data = df)
m10 <- lm(ena ~ migratory + seeds, data = df)
m11 <- lm(ena ~ latitude + I(latitude^2) + insects, data = df)
m12 <- lm(ena ~ latitude + I(latitude^2) + fruit + I(fruit^2), data = df)
m13 <- lm(ena ~ latitude + I(latitude^2) + seeds, data = df)
m14 <- lm(ena ~ migratory * latitude + I(latitude^2), data = df)
m15 <- lm(ena ~ migratory * insects, data = df)
m16 <- lm(ena ~ migratory * fruit + I(fruit^2), data = df)
m17 <- lm(ena ~ migratory * seeds, data = df)
m18 <- lm(ena ~ latitude * insects + I(latitude^2), data = df)
m19 <- lm(ena ~ latitude * fruit + I(latitude^2) + I(fruit^2), data = df)
m20 <- lm(ena ~ latitude * seeds + I(latitude^2), data = df)
m21 <- lm(ena ~ migratory + latitude + I(latitude^2) + insects, data=df)
m22 <- lm(ena ~ migratory + latitude + I(latitude^2) + fruit + I(fruit^2), data=df)
m23 <- lm(ena ~ migratory + latitude + I(latitude^2) + seeds, data=df)
m24 <- lm(ena ~ migratory * latitude * insects + I(latitude^2), data=df)
m25 <- lm(ena ~ migratory * latitude * fruit + I(latitude^2) + I(fruit^2), data=df)
m26 <- lm(ena ~ migratory * latitude * seeds + I(latitude^2), data=df)

sel <- model.sel(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,
                 m13,m14,m15,m16,m17,m18,m19,m20,m21,m22,m23,
                 m24,m25,m26)
sel
sw(sel)


## ATL
m1 <- lm(atl ~ 1, data = df)
m2 <- lm(atl ~ migratory, data = df)
m3 <- lm(atl ~ latitude + I(latitude^2), data=df)
m4 <- lm(atl ~ insects, data = df)
m5 <- lm(atl ~ fruit + I(fruit^2), data = df)
m6 <- lm(atl ~ seeds, data = df)
m7 <- lm(atl ~ migratory + latitude + I(latitude^2), data = df)
m8 <- lm(atl ~ migratory + insects, data = df)
m9 <- lm(atl ~ migratory + fruit + I(fruit^2), data = df)
m10 <- lm(atl ~ migratory + seeds, data = df)
m11 <- lm(atl ~ latitude + I(latitude^2) + insects, data = df)
m12 <- lm(atl ~ latitude + I(latitude^2) + fruit + I(fruit^2), data = df)
m13 <- lm(atl ~ latitude + I(latitude^2) + seeds, data = df)
m14 <- lm(atl ~ migratory * latitude + I(latitude^2), data = df)
m15 <- lm(atl ~ migratory * insects, data = df)
m16 <- lm(atl ~ migratory * fruit + I(fruit^2), data = df)
m17 <- lm(atl ~ migratory * seeds, data = df)
m18 <- lm(atl ~ latitude * insects + I(latitude^2), data = df)
m19 <- lm(atl ~ latitude * fruit + I(latitude^2) + I(fruit^2), data = df)
m20 <- lm(atl ~ latitude * seeds + I(latitude^2), data = df)
m21 <- lm(atl ~ migratory + latitude + I(latitude^2) + insects, data=df)
m22 <- lm(atl ~ migratory + latitude + I(latitude^2) + fruit + I(fruit^2), data=df)
m23 <- lm(atl ~ migratory + latitude + I(latitude^2) + seeds, data=df)
m24 <- lm(atl ~ migratory * latitude * insects + I(latitude^2), data=df)
m25 <- lm(atl ~ migratory * latitude * fruit + I(latitude^2) + I(fruit^2), data=df)
m26 <- lm(atl ~ migratory * latitude * seeds + I(latitude^2), data=df)

sel <- model.sel(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,
                 m13,m14,m15,m16,m17,m18,m19,m20,m21,m22,m23,
                 m24,m25,m26)
sel
sw(sel)


## MISS
m1 <- lm(miss ~ 1, data = df)
m2 <- lm(miss ~ migratory, data = df)
m3 <- lm(miss ~ latitude + I(latitude^2), data=df)
m4 <- lm(miss ~ insects, data = df)
m5 <- lm(miss ~ fruit + I(fruit^2), data = df)
m6 <- lm(miss ~ seeds, data = df)
m7 <- lm(miss ~ migratory + latitude + I(latitude^2), data = df)
m8 <- lm(miss ~ migratory + insects, data = df)
m9 <- lm(miss ~ migratory + fruit + I(fruit^2), data = df)
m10 <- lm(miss ~ migratory + seeds, data = df)
m11 <- lm(miss ~ latitude + I(latitude^2) + insects, data = df)
m12 <- lm(miss ~ latitude + I(latitude^2) + fruit + I(fruit^2), data = df)
m13 <- lm(miss ~ latitude + I(latitude^2) + seeds, data = df)
m14 <- lm(miss ~ migratory * latitude + I(latitude^2), data = df)
m15 <- lm(miss ~ migratory * insects, data = df)
m16 <- lm(miss ~ migratory * fruit + I(fruit^2), data = df)
m17 <- lm(miss ~ migratory * seeds, data = df)
m18 <- lm(miss ~ latitude * insects + I(latitude^2), data = df)
m19 <- lm(miss ~ latitude * fruit + I(latitude^2) + I(fruit^2), data = df)
m20 <- lm(miss ~ latitude * seeds + I(latitude^2), data = df)
m21 <- lm(miss ~ migratory + latitude + I(latitude^2) + insects, data=df)
m22 <- lm(miss ~ migratory + latitude + I(latitude^2) + fruit + I(fruit^2), data=df)
m23 <- lm(miss ~ migratory + latitude + I(latitude^2) + seeds, data=df)
m24 <- lm(miss ~ migratory * latitude * insects + I(latitude^2), data=df)
m25 <- lm(miss ~ migratory * latitude * fruit + I(latitude^2) + I(fruit^2), data=df)
m26 <- lm(miss ~ migratory * latitude * seeds + I(latitude^2), data=df)

sel <- model.sel(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,
                 m13,m14,m15,m16,m17,m18,m19,m20,m21,m22,m23,
                 m24,m25,m26)
sel
sw(sel)


## s_within (glms)
m1 <- glm(s_within ~ 1, data = df, family=Gamma)
m2 <- glm(s_within ~ migratory, data = df, family=Gamma)
m3 <- glm(s_within ~ latitude + I(latitude^2), data=df, family=Gamma)
m4 <- glm(s_within ~ insects, data = df, family=Gamma)
m5 <- glm(s_within ~ fruit + I(fruit^2), data = df, family=Gamma)
m6 <- glm(s_within ~ seeds, data = df, family=Gamma)
m7 <- glm(s_within ~ migratory + latitude + I(latitude^2), data = df, family=Gamma)
m8 <- glm(s_within ~ migratory + insects, data = df, family=Gamma)
m9 <- glm(s_within ~ migratory + fruit + I(fruit^2), data = df, family=Gamma)
m10 <- glm(s_within ~ migratory + seeds, data = df, family=Gamma)
m11 <- glm(s_within ~ latitude + I(latitude^2) + insects, data = df, family=Gamma)
m12 <- glm(s_within ~ latitude + I(latitude^2) + fruit + I(fruit^2), data = df, family=Gamma)
m13 <- glm(s_within ~ latitude + I(latitude^2) + seeds, data = df, family=Gamma)
m14 <- glm(s_within ~ migratory * latitude + I(latitude^2), data = df, family=Gamma)
m15 <- glm(s_within ~ migratory * insects, data = df, family=Gamma)
m16 <- glm(s_within ~ migratory * fruit + I(fruit^2), data = df, family=Gamma)
m17 <- glm(s_within ~ migratory * seeds, data = df, family=Gamma)
m18 <- glm(s_within ~ latitude * insects + I(latitude^2), data = df, family=Gamma)
m19 <- glm(s_within ~ latitude * fruit + I(latitude^2) + I(fruit^2), data = df, family=Gamma)
m20 <- glm(s_within ~ latitude * seeds + I(latitude^2), data = df, family=Gamma)
m21 <- glm(s_within ~ migratory + latitude + I(latitude^2) + insects, data=df, family=Gamma)
m22 <- glm(s_within ~ migratory + latitude + I(latitude^2) + fruit + I(fruit^2), data=df, family=Gamma)
m23 <- glm(s_within ~ migratory + latitude + I(latitude^2) + seeds, data=df, family=Gamma)
m24 <- glm(s_within ~ migratory * latitude * insects + I(latitude^2), data=df, family=Gamma)
m25 <- glm(s_within ~ migratory * latitude * fruit + I(latitude^2) + I(fruit^2), data=df, family=Gamma)
m26 <- glm(s_within ~ migratory * latitude * seeds + I(latitude^2), data=df, family=Gamma)

sel <- model.sel(m1,m2,m3,m4,m5,m6,m7,m8,m9,m10,m11,m12,
                 m13,m14,m15,m16,m17,m18,m19,m20,m21,m22,m23,
                 m24,m25,m26)
sel
sw(sel)


## Table 1 in the text lists some of the relevant output 
## for these models, including logLik, delta AICc,
## and variable weights.


